package cn.net.caoyao.cpzshandset.service.presenter.impl.activate.common;

import java.util.ArrayList;
import java.util.List;

import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;

import com.google.gson.Gson;

import cilico.tools.barcode.PhoneScanner;
import cn.net.caoyao.cpzshandset.R;
import cn.net.caoyao.cpzshandset.bean.ActivateBean;
import cn.net.caoyao.cpzshandset.bean.ConfigBean;
import cn.net.caoyao.cpzshandset.bean.SingleLabelOptionBean;
import cn.net.caoyao.cpzshandset.bean.SubmitBean;
import cn.net.caoyao.cpzshandset.common.config.Config;
import cn.net.caoyao.cpzshandset.common.config.HandsetOperation;
import cn.net.caoyao.cpzshandset.common.config.HandsetVersionConstant;
import cn.net.caoyao.cpzshandset.common.config.RequestConstant;
import cn.net.caoyao.cpzshandset.common.config.TConfig;
import cn.net.caoyao.cpzshandset.common.util.LogUtil;
import cn.net.caoyao.cpzshandset.common.util.NetWorkUtils;
import cn.net.caoyao.cpzshandset.common.util.StringUtils;
import cn.net.caoyao.cpzshandset.service.bll.ActivateBll;
import cn.net.caoyao.cpzshandset.service.bll.ActivateWithPackBll;
import cn.net.caoyao.cpzshandset.service.bll.ProductBll;
import cn.net.caoyao.cpzshandset.service.bll.SingleLabelBll;
import cn.net.caoyao.cpzshandset.service.bll.UploadStatusBll;
import cn.net.caoyao.cpzshandset.service.bll.config.ConfigBll;
import cn.net.caoyao.cpzshandset.service.presenter.SingleLabelScannerConstact;
import cn.net.caoyao.cpzshandset.service.presenter.base.impl.SingleLabelScannerConstactImpl;
import cn.net.caoyao.cpzshandset.service.thread.ThreadPoolManager;
import cn.net.caoyao.cpzshandset.service.thread.ThreadReqTools;
import cn.net.caoyao.cpzshandset.service.thread.impl.common.CommonSubmitSingleActivateThread;
import cn.net.caoyao.cpzshandset.ui.adapter.SingleLabelAdapter;
import cn.net.caoyao.cpzshandset.ui.dialog.TipsDialog;
import cn.net.caoyao.cpzshandset.ui.dialog.TipsDialog.DSure;
import cn.net.caoyao.cpzshandset.ui.weight.DialogUtils;
import cn.net.cpzslibs.prot.bean.res.ProtStatusResBean;
import cn.net.cpzslibs.prot.handset.bean.Product;
import cn.net.handsetlib.utils.ReadDeviceIDUtil;

public class CommonActivateSingleLSPresenter extends SingleLabelScannerConstactImpl {

	private final SingleLabelScannerConstact.View sView;
	private Context context;
	private SingleLabelBll labelBll;
	private ProductBll productBll;
	private ActivateBll activateBll;
	private ConfigBll configBll;
	private UploadStatusBll uploadStatusBll;
	private ActivateWithPackBll packBll;
	private ActivateBean currentActivate;
	private SingleLabelAdapter adapter;
	private List<SingleLabelOptionBean> labels = new ArrayList<>();
	private int option_id;
	private int currentHansetVersion = HandsetVersionConstant.HANDSET_UNIVERSAL_VERSION_MODE;
	private int option_type = HandsetOperation.OPERATION_ACTIVATE_CONSTANT.getOption();
	private int other_option_type = HandsetOperation.OPERATION_ACTIVATE_WITH_PACK_CONSTANT.getOption();
	private TextView tv_scanner_text_identify1, tv_scanner_text_identify2, tv_scanner_text_identify3,
			tv_scanner_text_identify4,tv_scanner_pici;
	private TipsDialog tipsDialog;
	private ProgressDialog bProgressDialog = null;
	private Handler mHandler = new Handler() {
		@Override
		public void handleMessage(Message msg) {
			switch (msg.what) {
			case PhoneScanner.BARCODE_READ:
			case PhoneScanner.BARCODE_ERR_LABEL: // 成功
				scannerSuccess(msg.obj.toString());
				break;
			case PhoneScanner.BARCODE_NOREAD:
				// 数据扫描失败
				if (checkViewAvailable()) {
					sView.showMsgToast("取消扫描", Toast.LENGTH_SHORT);
				}
				break;
			case RequestConstant.REQUEST_FAIL:
				//请求失败
				if (!checkViewAvailable())return;
				dismissProgress();
				sView.showMsgToast("请求失败！", Toast.LENGTH_SHORT);
				break;
			case RequestConstant.REQUEST_FAIL_SOCKET_TIMEOUT:
				//超时
				if (!checkViewAvailable())return;
				dismissProgress();
				sView.showMsgToast("请求超时！", Toast.LENGTH_SHORT);
				break;
			case RequestConstant.REQUEST_PROT01_LOGIN_FAIL:
				//登录失败
				if (!checkViewAvailable())return;
				dismissProgress();
				String errorMsg = msg.obj.toString();
				int errorCode = msg.arg1;
				sView.showMsgToast(errorMsg + errorCode, Toast.LENGTH_SHORT);
				break;
			case RequestConstant.SUBMIT_ACTIVATE_WITHOUT_RES:
				//服务器没有返回值
				if (!checkViewAvailable()) return;
				dismissProgress();
				sView.showMsgToast("抱歉，服务器没有反馈，请重试或者联系工作人员", Toast.LENGTH_SHORT);
				break;
			case RequestConstant.SUBMIT_ACTIVATE_WITH_RES:
				//服务器没有返回值
				if (!checkViewAvailable()) return;
				dismissProgress();
				SubmitBean resBean = (SubmitBean) msg.obj;
				if (resBean.getCode() == 200) {
					sView.showMsgToast("上传数据成功！" , Toast.LENGTH_SHORT);
					sView.finishPage();
				} else {
					currentActivate = activateBll.queryActivateBeanById(option_id);
					labels = labelBll.queryAllLabelById(option_type, option_id);
					adapter.refreshData(labels);
					setLabelStatusData2(resBean.getMsg());
				}
				
				break;
			}

		}

	};

	@Override
	public void scannerSuccess(String str) {
		if (!checkViewAvailable()) return;
		LogUtil.d(TConfig.Echo, "scannerRecuess：" + str);
//		sView.vibrate(100);
		super.scannerSuccess(str);
		if (StringUtils.isEmpty(str)) {
			sView.showMsgToast("扫描标签不能为空！", Toast.LENGTH_SHORT);
			return;
		}
		if (!StringUtils.isNumber(str)) {
			sView.showMsgToast("您所扫描的不是中国追溯的合法标签！", Toast.LENGTH_SHORT);
			return;
		}
		if (!(str.length() == 16)) {
			sView.showMsgToast("您所扫描的不是中国追溯的合法标签！"+ str.length(), Toast.LENGTH_SHORT);
			return;
		}
		if (packBll.isPackageIdInAWithPack(str)) {
			String tips = "该标签存在于本地未上传的生产打包列表中：\n" + str;
			showIKnowTipsDialog(tips);
			return;
		}
		/*if (labelBll.hasExistSingleLabel(str, other_option_type)) {
			String tips = "该标签存在于本地未上传的激活打包列表中：\n" + str;
			showIKnowTipsDialog(tips);
			return;
		}*/
		if (labelBll.hasExistSingleLabel(str, option_type)) {
//			String tips = "本地已经存在未上传的激活标签：\n" + str;
			String tips = "本地已经存在未上传的标签：\n" + str;
			showIKnowTipsDialog(tips);
			return;
		}
		if (labelBll.isMaxLimitCount(option_type, option_id)) {
			String tips = "抱歉，本次激活列表已达到上限，请重新建立激活信息扫描";
			showIKnowTipsDialog(tips);
			return;
		}
//		LogUtil.d(TConfig.Echo, "option_type: " + option_type +"  option_id:"+option_id);
		labelBll.insertLabel(new SingleLabelOptionBean(str, option_type, option_id));
		labels = labelBll.queryAllLabelById(option_type, option_id);
		adapter.refreshData(labels);
		setLabelCountData();
//		labels.add(new SingleLabelOptionBean(str, option_type, option_id));
		LogUtil.d(TConfig.Echo, "labels：" + labels.size());
//		adapter.refreshData(labels);
	}

	private void showIKnowTipsDialog(String tips) {
		if (tipsDialog == null) {
			tipsDialog = new TipsDialog(context);
		}
		tipsDialog.show();
		tipsDialog.setWarnView("提示", tips, true, null);
	}
	
	private void showDelTipsDialog(final int position,String tipContent){
		if (tipsDialog == null) {
			tipsDialog = new TipsDialog(context);
		}
		tipsDialog.show();
		tipsDialog.setDelWarnView("提示", tipContent, position, false, new DSure() {
			
			@Override
			public void sureClick() {
				SingleLabelOptionBean b = labels.get(position);
				labelBll.deleteLabelByLabelId(b);
				labels = labelBll.queryAllLabelById(option_type, option_id);
				if (labels.size() == 0) {
					activateBll.updateActivateNotSubmitStatusById(option_id);
					setLabelStatusData();
				}
				adapter.refreshData(labels);
				setLabelCountData();
			}
		});
	}

	public CommonActivateSingleLSPresenter(SingleLabelScannerConstact.View sView, Context context, Intent intent) {
		super(sView, context);
		this.sView = sView;
		this.context = context;
		currentActivate = (ActivateBean) intent.getSerializableExtra("currentActivateBean");
		option_id = currentActivate.getId();
		start();
	}

	@Override
	public void start() {
		if (!checkViewAvailable())
			return;
		init();
		View customView = LayoutInflater.from(context).inflate(R.layout.scanner_custom_diaplay_layout, null);
		initCustomView(customView);
		sView.setMoreOptionStr("上传");
		sView.setPageTitle("单标激活");
		adapter = new SingleLabelAdapter(labels);
		sView.addHeadView(customView);
		sView.setAdapter(adapter);
		labels = labelBll.queryAllLabelById(HandsetOperation.OPERATION_ACTIVATE_CONSTANT.getOption(),
				currentActivate.getId());
		adapter.refreshData(labels);
//		Product p = productBll.queryProductById(currentActivate.getProduct_id());
		tv_scanner_text_identify1.setText("产品名称：" + currentActivate.getProducer());
		tv_scanner_pici.setText("批次号：" + currentActivate.getProduct_batch_name());
		String pDate = StringUtils.isEmpty(currentActivate.getProduct_date()) ? "无":currentActivate.getProduct_date();
		tv_scanner_text_identify2.setText("等级：" + pDate);
		setLabelCountData();
		setLabelStatusData();
	}

	private void setLabelCountData() {
		tv_scanner_text_identify3.setText("标签数量：" + labels.size());
	}

	private void setLabelStatusData() {
		if (currentActivate.getStatus() == Config.SUBMIT_STATUS_NOT_SUBMIT) {
			tv_scanner_text_identify4.setText("状态：未提交");
		} else {
			tv_scanner_text_identify4.setText("状态：提交失败  错误码：" + currentActivate.getError_code() +"\n原因："+ ThreadReqTools.getErrorMsg(currentActivate.getError_code()) );
		}
	}
	private void setLabelStatusData2(String msg) {
		if (currentActivate.getStatus() == Config.SUBMIT_STATUS_NOT_SUBMIT) {
			tv_scanner_text_identify4.setText("状态：未提交");
		} else {
//			tv_scanner_text_identify4.setText("状态：提交失败  错误码：" + currentActivate.getError_code() +"\n原因："+ ThreadReqTools.getErrorMsg(currentActivate.getError_code()) );
			tv_scanner_text_identify4.setText("状态：提交失败  错误码：" + currentActivate.getError_code() +"\n原因："+ msg );
		}
	}

	private void initCustomView(View v) {
		tv_scanner_text_identify1 = (TextView) v.findViewById(R.id.tv_scanner_text_identify1);
		tv_scanner_text_identify2 = (TextView) v.findViewById(R.id.tv_scanner_text_identify2);
		tv_scanner_text_identify3 = (TextView) v.findViewById(R.id.tv_scanner_text_identify3);
		tv_scanner_text_identify4 = (TextView) v.findViewById(R.id.tv_scanner_text_identify4);
		tv_scanner_pici = (TextView) v.findViewById(R.id.tv_scanner_pici);
	}

	private void init() {
		labelBll = new SingleLabelBll(context);
		productBll = new ProductBll(context);
		activateBll = new ActivateBll(context);
		configBll = new ConfigBll(context);
		uploadStatusBll = new UploadStatusBll(context);
		packBll = new ActivateWithPackBll(context);
	}

	@Override
	public boolean checkViewAvailable() {
		boolean b = false;
		if (sView != null && context != null) {
			b = true;
		}
		return b;
	}

	@Override
	public Handler getHandler() {
		return mHandler;
	}

	@Override
	public void onActivityResult(int requestCode, int resultCode, Intent data) {
		// TODO Auto-generated method stub

	}

	@Override
	public void onResume() {
		// TODO Auto-generated method stub

	}

	@Override
	public void backClick() {
		// TODO Auto-generated method stub

	}

	@Override
	public void btnScannerClick() {
		if (!checkViewAvailable())
			return;
		sView.readQRCode();
	}

	@Override
	public void uploadClick() {
		if (!checkViewAvailable()) return;
//		ConfigBean configBean = configBll.queryConfigByHandsetMode(currentHansetVersion);
//		if (configBean == null) {
//			sView.showMsgToast("当前设备还未配置过手持机id，请先配置手持机的设备id", Toast.LENGTH_SHORT);
//			return;
//		}
		if (labels.size() <= 0){
			sView.showMsgToast("当前的激活单还没有标签，不能上传", Toast.LENGTH_SHORT);
			return;
		}
//		if (!NetWorkUtils.isNetworkConnected(context)) {
//			DialogUtils.showSetNetDialog(context);
//			return;
//		}
		showProgressDialog("提示", "正在提交激活信息，请稍后……");
//		long deviceId = Long.parseLong(ReadDeviceIDUtil.readScanDecrypt(configBean.getDeviceId()));
		ThreadPoolManager.getThreadPool().execute(new CommonSubmitSingleActivateThread(mHandler, 0, activateBll, labelBll,uploadStatusBll, currentActivate, labels,context));
	}
	
	public void dismissProgress() {
		if (bProgressDialog != null) {
			try {
				DialogUtils.dismissProgressDialog(bProgressDialog);
			} catch (Exception e) {
			}
		}
	}

	/**
	 * 提示正在更新数据
	 */
	protected void showProgressDialog(String titleStr, String tipsMsg) {
		bProgressDialog = DialogUtils.showProgressDialog(bProgressDialog, titleStr,
				tipsMsg, context);
	}

	@Override
	public void onItemClickLinstener(int position) {
//		int currentPos = labels.size() - position - 1;
		if (position > 0) {
			SingleLabelOptionBean b = labels.get(position - 1);
			String tipsContent = "确认删除激活标签：\n" + b.getLabel_id();
			showDelTipsDialog(position -1,tipsContent);
		}
		
	}

	@Override
	public void onItemLongClickListener(int position) {
		

	}

}
